#! /usr/bin/perl

# this script takes 1. a pto file, 2. n image files
# it locates the image files in the pto and makes multiple output
# ptos for each image exposure level.
# also creates .hdrgen for the resulting panorama
use strict;
use warnings;

use Panotools::Script;


use Image::ExifTool;



my $base_pto = shift @ARGV;
$base_pto =~ /^(.*)\.pto$/;
my $base_prefix = $1;

my %stack;
my $stacknum=0;
my @stacklist;
my %images;
for my $i (@ARGV) {
my $ex = new Image::ExifTool;
$ex->ExtractInfo($i);
my $et = 1/$ex->GetValue('ExposureTime','ValueConv');
my $fn = $ex->GetValue('FNumber','ValueConv');
my $is = $ex->GetValue('ISO','ValueConv');
# exposure level, just a tracking variable
# and, oddly, exactly the same format as hdrgen...
my $el = $et." ".$fn." ".$is;
if (defined $stack{$el} && $stack{$el} == 1 ) {
  %stack=();
  $stacknum++;
};
$stack{$el}=1;
$stacklist[$stacknum]->{$el} = $i;
$images{$i}=$stacknum;
};

my @ev = sort(keys %{$stacklist[0]});

# now, process the .pto
my $p = new Panotools::Script;
$p->Read($base_pto);
my $count=1;
open HDRGEN,">",$base_prefix.".hdrgen";
for my $exp (@ev) {
  # find the images.
  
  my $imagelines = $p->Image;
  for my $idx (0 .. scalar (@$imagelines) - 1 ) {
    my $imgname = $imagelines->[$idx]->{'n'};
    # find which stack this image is in
    $imgname =~ /^("?)(.*?)("?)$/ ;
    my $imgbase = $2;
    my $st = $images{$imgbase};
    # now, find which image we really want
    my $imgwanted = '"'. $stacklist[$st]->{$exp} .'"';
    $imagelines->[$idx]->Set('n',$imgwanted);
  };
  #output the .pto
  $p->Write($base_prefix."_".$count.".pto");
  print HDRGEN $base_prefix."_".$count.".tiff ".$exp." 0\n";
  $count++;
};
close HDRGEN;





